@@ -25,7 +25,7 @@ def job():
     global d
     d = {}
     d['t'] = time.ctime()  # 后台更新全局变量
-    d['f'] = open('file.txt').read()  # 后台更新全局变量
+    d['f'] = open('main.py').read()  # 后台更新全局变量
 
 
 job()
